@@ -4,6 +4,39 @@ set -euo pipefail
 # shellcheck disable=SC2155
 SOURCE_ROOT="${VIBEGO_PACKAGE_ROOT:-$(cd "$(dirname "${BASH_SOURCE[0]}")/.." && pwd)}"
 
+pick_python_bin() {
+  if [[ -n "${VIBEGO_PYTHON_BIN:-}" ]]; then
+    printf '%s' "$VIBEGO_PYTHON_BIN"
+    return 0
+  fi
+  local candidate
+  for candidate in python3.11 python3.10 python3.9 python3; do
+    if command -v "$candidate" >/dev/null 2>&1; then
+      printf '%s' "$candidate"
+      return 0
+    fi
+  done
+  return 1
+}
+
+PYTHON_BIN="$(pick_python_bin)" || {
+  echo "[run-bot] 未检测到可用的 python3，请先安装 Python>=3.9" >&2
+  exit 1
+}
+
+PY_VERSION_OUTPUT="$("$PYTHON_BIN" - <<'PY'
+import sys
+print(sys.version_info.major, sys.version_info.minor, sys.version_info.micro)
+PY
+)"
+read -r PY_MAJOR PY_MINOR PY_MICRO <<<"$PY_VERSION_OUTPUT"
+PY_VERSION_STR="${PY_MAJOR}.${PY_MINOR}.${PY_MICRO}"
+if (( PY_MAJOR < 3 || (PY_MAJOR == 3 && PY_MINOR < 9) )); then
+  echo "[run-bot] 当前 Python 版本 $PY_VERSION_STR 不满足 >=3.9 要求" >&2
+  exit 1
+fi
+echo "[run-bot] 使用 Python: $PY_VERSION_STR ($PYTHON_BIN)"
+
 resolve_config_root() {
   local raw=""
   if [[ -n "${MASTER_CONFIG_ROOT:-}" ]]; then
@@ -34,11 +67,11 @@ PROJECT_DEFAULT="${PROJECT_NAME:-}"
 
 usage() {
   cat <<USAGE
-usage:${0##*/} [--model name] [--project name] [--foreground] [--no-stop]
-  --model        Start the specified model (codex|claudecode|gemini), default: $MODEL_DEFAULT
-  --project      Specify project alias for logging/Conversation distinction
-  --foreground   Run in foreground(for debugging), defaultBackstage
-  --no-stop      Not executed before startup stop_bot.sh(defaultOld instances will be stopped first)
+用法：${0##*/} [--model 名称] [--project 名称] [--foreground] [--no-stop]
+  --model        启动指定模型 (codex|claudecode|gemini)，默认: $MODEL_DEFAULT
+  --project      指定项目别名，用于日志/会话区分
+  --foreground   在前台运行（调试用），默认后台
+  --no-stop      启动前不执行 stop_bot.sh（默认会先停旧实例）
 USAGE
 }
 
@@ -60,7 +93,7 @@ while [[ $# -gt 0 ]]; do
     -h|--help)
       usage; exit 0 ;;
     *)
-      echo "unknown parameters: $1" >&2
+      echo "未知参数: $1" >&2
       usage
       exit 1 ;;
   esac
@@ -68,14 +101,14 @@ done
 
 MODEL_SCRIPT="$MODELS_DIR/$MODEL.sh"
 if [[ ! -f "$MODEL_SCRIPT" ]]; then
-  echo "[run-bot] Unsupported model: $MODEL" >&2
+  echo "[run-bot] 不支持的模型: $MODEL" >&2
   exit 1
 fi
 
-# Load public functions + Model configuration
+# 加载公共函数 + 模型配置
 # shellcheck disable=SC1090
 source "$MODELS_DIR/common.sh"
-# Allow model scripts to reuse environment variables
+# 允许模型脚本重用环境变量
 MODEL_WORKDIR="${MODEL_WORKDIR:-}" 
 # shellcheck disable=SC1090
 source "$MODEL_SCRIPT"
@@ -90,7 +123,6 @@ LOG_DIR="$(log_dir_for "$MODEL" "$PROJECT_NAME")"
 MODEL_LOG="$LOG_DIR/model.log"
 RUN_LOG="$LOG_DIR/run_bot.log"
 POINTER_FILE="$LOG_DIR/${MODEL_POINTER_BASENAME:-current_session.txt}"
-LOCK_FILE="${SESSION_LOCK_FILE:-$LOG_DIR/${MODEL_POINTER_LOCK_BASENAME:-session_lock.json}}"
 TMUX_SESSION="$(tmux_session_for "$PROJECT_NAME")"
 
 expand_model_workdir() {
@@ -105,24 +137,24 @@ expand_model_workdir() {
 MODEL_WORKDIR="$(expand_model_workdir "$MODEL_WORKDIR")"
 
 if [[ -z "$MODEL_WORKDIR" ]]; then
-  echo "[run-bot] Configuration is missing MODEL_WORKDIR, Please check config/projects.json" >&2
+  echo "[run-bot] 配置缺少 MODEL_WORKDIR，请检查 config/projects.json" >&2
   exit 1
 fi
 
 if [[ ! -d "$MODEL_WORKDIR" ]]; then
-  echo "[run-bot] Working directory does not exist: $MODEL_WORKDIR" >&2
+  echo "[run-bot] 工作目录不存在: $MODEL_WORKDIR" >&2
   exit 1
 fi
 
 if ! command -v tmux >/dev/null 2>&1; then
-  echo "[run-bot] tmux not detected, pass 'brew install tmux' Install" >&2
+  echo "[run-bot] 未检测到 tmux，可通过 'brew install tmux' 安装" >&2
   exit 1
 fi
 
 if [[ -n "$MODEL_CMD" ]]; then
   IFS=' ' read -r MODEL_CMD_BIN _ <<<"$MODEL_CMD"
   if [[ -n "$MODEL_CMD_BIN" ]] && ! command -v "$MODEL_CMD_BIN" >/dev/null 2>&1; then
-    echo "[run-bot] Model command not detected: $MODEL_CMD_BIN" >&2
+    echo "[run-bot] 未检测到模型命令: $MODEL_CMD_BIN" >&2
     exit 1
   fi
 fi
@@ -134,7 +166,7 @@ if (( FOREGROUND == 0 )); then
   CMD=("$0" --model "$MODEL" --project "$PROJECT_NAME" --foreground)
   (( NO_STOP )) && CMD+=(--no-stop)
   nohup "${CMD[@]}" >>"$RUN_LOG" 2>&1 &
-  echo "[run-bot] Start in background (model=$MODEL project=$PROJECT_NAME) log: $RUN_LOG"
+  echo "[run-bot] 后台启动 (model=$MODEL project=$PROJECT_NAME) 日志: $RUN_LOG"
   exit 0
 fi
 
@@ -145,13 +177,13 @@ fi
 mkdir -p "$RUNTIME_ROOT"
 
 if [[ ! -d "$VENV_DIR" ]]; then
-  python3 -m venv "$VENV_DIR"
+  "$PYTHON_BIN" -m venv "$VENV_DIR"
 fi
 # shellcheck disable=SC1091
 source "$VENV_DIR/bin/activate"
 REQUIREMENTS_PATH="${VIBEGO_REQUIREMENTS_PATH:-$SOURCE_ROOT/scripts/requirements.txt}"
 if [[ ! -f "$REQUIREMENTS_PATH" ]]; then
-  echo "[run-bot] Dependency list not found: $REQUIREMENTS_PATH" >&2
+  echo "[run-bot] 未找到依赖清单: $REQUIREMENTS_PATH" >&2
   exit 1
 fi
 if [[ ! -f "$VENV_DIR/.requirements.installed" ]] || [[ "$REQUIREMENTS_PATH" -nt "$VENV_DIR/.requirements.installed" ]]; then
@@ -168,13 +200,20 @@ export MODEL_SESSION_ROOT
 export MODEL_SESSION_GLOB
 export SESSION_POINTER_FILE="$POINTER_FILE"
 export CODEX_SESSION_FILE_PATH="$POINTER_FILE"
-export SESSION_LOCK_FILE="$LOCK_FILE"
-export SESSION_LOCK_FILE_PATH="$LOCK_FILE"
+SESSION_ACTIVE_ID_FILE="${SESSION_ACTIVE_ID_FILE:-$LOG_DIR/active_session_id.txt}"
+export SESSION_ACTIVE_ID_FILE
+SESSION_BINDER_LOG="${SESSION_BINDER_LOG:-$LOG_DIR/session_binder.log}"
+export SESSION_BINDER_LOG
 export TMUX_SESSION="$TMUX_SESSION"
 export TMUX_LOG="$MODEL_LOG"
 export PROJECT_NAME="$PROJECT_NAME"
 export LOG_DIR="$LOG_DIR"
 export ROOT_DIR="$SOURCE_ROOT"
+export SESSION_BIND_STRICT="${SESSION_BIND_STRICT:-1}"
+export SESSION_BIND_TIMEOUT_SECONDS="${SESSION_BIND_TIMEOUT_SECONDS:-30}"
+export SESSION_BIND_POLL_INTERVAL="${SESSION_BIND_POLL_INTERVAL:-0.5}"
+export SESSION_BINDER_POLL_INTERVAL="${SESSION_BINDER_POLL_INTERVAL:-0.5}"
+export SESSION_BINDER_TIMEOUT="${SESSION_BINDER_TIMEOUT:-600}"
 if [[ -n "${CLAUDE_CODE_DISABLE_FILE_CHECKPOINTING:-}" ]]; then
   export CLAUDE_CODE_DISABLE_FILE_CHECKPOINTING
 fi
