@@ -18,13 +18,13 @@ MODEL_WORKDIR="${MODEL_WORKDIR:-$ROOT_DIR}"
 MODEL_SESSION_ROOT="${MODEL_SESSION_ROOT:-${CODEX_SESSION_ROOT:-$HOME/.codex/sessions}}"
 MODEL_SESSION_GLOB="${MODEL_SESSION_GLOB:-rollout-*.jsonl}"
 SESSION_POINTER_FILE="${SESSION_POINTER_FILE:-$LOG_ROOT/${MODEL_NAME:-codex}/${PROJECT_NAME:-project}/current_session.txt}"
-SESSION_LOCK_FILE="${SESSION_LOCK_FILE:-${SESSION_POINTER_FILE%.txt}.lock.json}"
-SESSION_CAPTURE_TIMEOUT="${SESSION_CAPTURE_TIMEOUT:-180}"
-SESSION_CAPTURE_POLL_INTERVAL="${SESSION_CAPTURE_POLL_INTERVAL:-0.5}"
-# Ensure optional CODEX session root is always defined even under `set -u`
-: "${CODEX_SESSIONS_ROOT:=}"
+SESSION_ACTIVE_ID_FILE="${SESSION_ACTIVE_ID_FILE:-$(dirname "${SESSION_POINTER_FILE}")/active_session_id.txt}"
+SESSION_BINDER="${SESSION_BINDER:-$ROOT_DIR/scripts/session_binder.py}"
+SESSION_BINDER_POLL_INTERVAL="${SESSION_BINDER_POLL_INTERVAL:-0.5}"
+SESSION_BINDER_TIMEOUT="${SESSION_BINDER_TIMEOUT:-600}"
+SESSION_BINDER_LOG="${SESSION_BINDER_LOG:-$(dirname "${SESSION_POINTER_FILE}")/session_binder.log}"
 
-# Avoid oh-my-zsh popping up update prompts in non-interactive environments
+# 避免 oh-my-zsh 在非交互环境弹出更新提示
 export DISABLE_UPDATE_PROMPT="${DISABLE_UPDATE_PROMPT:-true}"
 
 expand_path() {
@@ -45,7 +45,7 @@ KILL_SESSION=0
 
 usage() {
   cat <<USAGE
-usage:${0##*/} [--dry-run] [--force] [--restart] [--kill]
+用法：${0##*/} [--dry-run] [--force] [--restart] [--kill]
 USAGE
 }
 
@@ -56,13 +56,13 @@ while [[ $# -gt 0 ]]; do
     --restart) RESTART=1; FORCE_START=1 ;;
     --kill) KILL_SESSION=1 ;;
     -h|--help) usage; exit 0 ;;
-    *) echo "unknown parameters: $1" >&2; usage; exit 1 ;;
+    *) echo "未知参数: $1" >&2; usage; exit 1 ;;
   esac
   shift
 done
 
 if ! command -v tmux >/dev/null 2>&1; then
-  echo "tmux Not installed" >&2
+  echo "tmux 未安装" >&2
   exit 1
 fi
 
@@ -72,7 +72,8 @@ MODEL_SESSION_ROOT=$(expand_path "$MODEL_SESSION_ROOT")
 SESSION_POINTER_FILE=$(expand_path "$SESSION_POINTER_FILE")
 ensure_dir "$(dirname "$LOG_PATH")"
 ensure_dir "$(dirname "$SESSION_POINTER_FILE")"
-ensure_dir "$(dirname "$SESSION_LOCK_FILE")"
+ensure_dir "$(dirname "$SESSION_ACTIVE_ID_FILE")"
+ensure_dir "$(dirname "$SESSION_BINDER_LOG")"
 
 run_tmux() {
   if (( DRY_RUN )); then
@@ -104,12 +105,12 @@ else
   fi
 fi
 
-# Clean up before starting to avoid old logs exceeding the limit.
+# 启动前先进行一次清理，避免旧日志超限
 if ! env \
   MODEL_LOG_MAX_BYTES="$MODEL_LOG_MAX_BYTES" \
   MODEL_LOG_RETENTION_SECONDS="$MODEL_LOG_RETENTION_SECONDS" \
   "$PYTHON_EXEC" "$LOG_WRITER" "$LOG_PATH" </dev/null; then
-  echo "Preprocessing log file failed" >&2
+  echo "预处理日志文件失败" >&2
   exit 1
 fi
 
@@ -121,7 +122,7 @@ printf -v PIPE_CMD 'env MODEL_LOG_MAX_BYTES=%q MODEL_LOG_RETENTION_SECONDS=%q %q
   "$LOG_PATH"
 run_tmux pipe-pane -o -t "$SESSION_NAME" "$PIPE_CMD"
 
-# Synchronize environment variables to the tmux server to avoid losing settings when reusing old sessions
+# 同步环境变量到 tmux 服务端，避免复用旧会话时丢失设置
 run_tmux set-environment -t "$SESSION_NAME" DISABLE_UPDATE_PROMPT "${DISABLE_UPDATE_PROMPT:-true}"
 if [[ -n "${CLAUDE_CODE_DISABLE_FILE_CHECKPOINTING:-}" ]]; then
   run_tmux set-environment -t "$SESSION_NAME" CLAUDE_CODE_DISABLE_FILE_CHECKPOINTING "${CLAUDE_CODE_DISABLE_FILE_CHECKPOINTING}"
@@ -144,29 +145,47 @@ fi
 
 
 if (( DRY_RUN )); then
-  printf '[dry-run] Session log path: %s\n' "$SESSION_POINTER_FILE"
+  printf '[dry-run] 会话日志路径: %s\n' "$SESSION_POINTER_FILE"
   exit 0
 fi
 
 : > "$SESSION_POINTER_FILE"
-rm -f "$SESSION_LOCK_FILE"
+: > "$SESSION_ACTIVE_ID_FILE"
 
-if (( ! DRY_RUN )); then
-  WATCH_ARGS=("$PYTHON_EXEC" "$ROOT_DIR/scripts/session_pointer_watch.py" "--pointer" "$SESSION_POINTER_FILE" "--lock" "$SESSION_LOCK_FILE" "--glob" "$MODEL_SESSION_GLOB" "--workdir" "$MODEL_WORKDIR" "--tmux-session" "$SESSION_NAME" "--project" "${PROJECT_NAME:-}")
+if [[ -n "$SESSION_BINDER" ]] && [[ -f "$SESSION_BINDER" ]]; then
+  BIND_BOOT_TS="$("$PYTHON_EXEC" - <<'PY'
+import time
+print(int(time.time() * 1000))
+PY
+)"
+  BINDER_CMD=(
+    "$PYTHON_EXEC" "$SESSION_BINDER"
+    --pointer "$SESSION_POINTER_FILE"
+    --glob "$MODEL_SESSION_GLOB"
+    --boot-ts-ms "$BIND_BOOT_TS"
+    --poll-interval "$SESSION_BINDER_POLL_INTERVAL"
+    --timeout "$SESSION_BINDER_TIMEOUT"
+  )
   if [[ -n "$MODEL_SESSION_ROOT" ]]; then
-    WATCH_ARGS+=("--session-root" "$MODEL_SESSION_ROOT")
+    BINDER_CMD+=(--session-root "$MODEL_SESSION_ROOT")
   fi
-  if [[ -n "$CODEX_SESSIONS_ROOT" ]]; then
-    WATCH_ARGS+=("--additional-root" "$CODEX_SESSIONS_ROOT")
+  if [[ -n "${CODEX_SESSION_ROOT:-}" ]]; then
+    BINDER_CMD+=(--session-root "$CODEX_SESSION_ROOT")
   fi
-  WATCH_ARGS+=("--additional-root" "$(dirname "$SESSION_POINTER_FILE")")
-  WATCH_ARGS+=("--additional-root" "$(dirname "$SESSION_POINTER_FILE")/sessions")
-  WATCH_ARGS+=("--timeout" "$SESSION_CAPTURE_TIMEOUT")
-  WATCH_ARGS+=("--poll" "$SESSION_CAPTURE_POLL_INTERVAL")
-  if ! "${WATCH_ARGS[@]}"; then
-    echo "Failed to capture Codex/Claude session log for tmux session '$SESSION_NAME'. Please check CLI startup output." >&2
-    exit 1
+  BINDER_CMD+=(--session-root "$(dirname "$SESSION_POINTER_FILE")")
+  BINDER_CMD+=(--session-root "$(dirname "$SESSION_POINTER_FILE")/sessions")
+  if [[ -n "$MODEL_WORKDIR" ]]; then
+    BINDER_CMD+=(--cwd "$MODEL_WORKDIR")
   fi
+  if [[ -n "$SESSION_ACTIVE_ID_FILE" ]]; then
+    BINDER_CMD+=(--session-id-file "$SESSION_ACTIVE_ID_FILE")
+  fi
+  if [[ -n "$SESSION_BINDER_LOG" ]]; then
+    BINDER_CMD+=(--log "$SESSION_BINDER_LOG")
+  fi
+  nohup "${BINDER_CMD[@]}" >>"$SESSION_BINDER_LOG" 2>&1 &
+else
+  echo "[start-tmux] session binder 未找到：$SESSION_BINDER" >&2
 fi
 
 exit 0
