@@ -3,11 +3,12 @@ os.environ.setdefault("BOT_TOKEN", "dummy-token")
 
 import asyncio
 import json
+import subprocess
 from unittest.mock import AsyncMock
 from types import SimpleNamespace
 
 from aiogram.exceptions import TelegramBadRequest
-from aiogram.types import MenuButtonCommands, ReplyKeyboardMarkup, KeyboardButton, InlineKeyboardMarkup
+from aiogram.types import MenuButtonCommands, ReplyKeyboardMarkup, KeyboardButton
 
 import bot
 import master
@@ -37,36 +38,16 @@ def test_worker_keyboard_structure():
     assert len(markup.keyboard) == 2
     assert len(markup.keyboard[0]) == 2
     assert len(markup.keyboard[1]) == 1
-    for button in markup.keyboard[0]:
-        assert isinstance(button, KeyboardButton)
-    assert isinstance(markup.keyboard[1][0], KeyboardButton)
+    for row in markup.keyboard:
+        for button in row:
+            assert isinstance(button, KeyboardButton)
 
 
 def test_worker_keyboard_button_text():
     markup = bot._build_worker_main_keyboard()
     assert markup.keyboard[0][0].text == bot.WORKER_MENU_BUTTON_TEXT
-    assert markup.keyboard[0][1].text == bot.WORKER_CREATE_TASK_BUTTON_TEXT
-    assert markup.keyboard[1][0].text == bot.WORKER_COMMAND_BUTTON_TEXT
-
-
-def test_worker_menu_buttons_are_treated_as_menu_controls():
-    for label in (
-        bot.WORKER_MENU_BUTTON_TEXT,
-        bot.WORKER_CREATE_TASK_BUTTON_TEXT,
-        bot.WORKER_COMMAND_BUTTON_TEXT,
-    ):
-        assert bot._is_menu_control_message(label)
-        numbered = f"1. {label}"
-        assert bot._is_menu_control_message(numbered)
-
-
-def test_worker_button_variants_include_translations():
-    assert "📋 Task List" in bot.WORKER_MENU_BUTTON_TEXT_VARIANTS
-    assert "📋 任务列表" in bot.WORKER_MENU_BUTTON_TEXT_VARIANTS
-    assert "➕ Create Task" in bot.WORKER_CREATE_TASK_BUTTON_TEXT_VARIANTS
-    assert "➕ 创建任务" in bot.WORKER_CREATE_TASK_BUTTON_TEXT_VARIANTS
-    assert "⚙️ Command Center" in bot.WORKER_COMMAND_BUTTON_TEXT_VARIANTS
-    assert "⚙️ 命令管理" in bot.WORKER_COMMAND_BUTTON_TEXT_VARIANTS
+    assert markup.keyboard[0][1].text == bot.WORKER_COMMANDS_BUTTON_TEXT
+    assert markup.keyboard[1][0].text == bot.WORKER_TERMINAL_SNAPSHOT_BUTTON_TEXT
 
 
 def test_worker_keyboard_resize_enabled():
@@ -94,19 +75,16 @@ def test_master_menu_button_handles_bad_request(caplog):
 def test_master_keyboard_structure():
     markup = master._build_master_main_keyboard()
     assert isinstance(markup, ReplyKeyboardMarkup)
-    assert len(markup.keyboard) == 2
+    assert len(markup.keyboard) == 1
     assert len(markup.keyboard[0]) == 2
-    assert len(markup.keyboard[1]) == 1
     assert isinstance(markup.keyboard[0][0], KeyboardButton)
     assert isinstance(markup.keyboard[0][1], KeyboardButton)
-    assert isinstance(markup.keyboard[1][0], KeyboardButton)
 
 
 def test_master_keyboard_button_text():
     markup = master._build_master_main_keyboard()
     assert markup.keyboard[0][0].text == master.MASTER_MENU_BUTTON_TEXT
     assert markup.keyboard[0][1].text == master.MASTER_MANAGE_BUTTON_TEXT
-    assert markup.keyboard[1][0].text == master.MASTER_COMMAND_BUTTON_TEXT
 
 
 def test_master_keyboard_resize_enabled():
@@ -180,7 +158,7 @@ def test_master_broadcast_handles_empty_targets(caplog):
 
 
 class _DummyMessage:
-    """Used to simulate test messages triggered by master project buttons."""
+    """用于模拟 master 项目按钮触发的测试消息。"""
 
     def __init__(self, text: str, chat_id: int = 999, message_id: int = 123) -> None:
         self.text = text
@@ -195,7 +173,7 @@ class _DummyMessage:
 
 
 class _DummyManager:
-    """Impersonates the authorized master manager."""
+    """模拟授权通过的 master manager。"""
 
     def __init__(self) -> None:
         self.invocations = []
@@ -205,6 +183,46 @@ class _DummyManager:
         return True
 
 
+def test_worker_terminal_snapshot_success(monkeypatch):
+    captured_lines = {}
+
+    def fake_capture(lines: int) -> str:
+        captured_lines["value"] = lines
+        return "line-1\nline-2"
+
+    mock_reply_large_text = AsyncMock(return_value="sent")
+
+    monkeypatch.setattr(bot, "_capture_tmux_recent_lines", fake_capture)
+    monkeypatch.setattr(bot, "reply_large_text", mock_reply_large_text)
+
+    message = _DummyMessage(bot.WORKER_TERMINAL_SNAPSHOT_BUTTON_TEXT)
+    asyncio.run(bot.on_tmux_snapshot_button(message))
+
+    assert "value" in captured_lines
+    assert captured_lines["value"] == bot.TMUX_SNAPSHOT_LINES
+    assert mock_reply_large_text.await_count == 1
+    sent_text = mock_reply_large_text.await_args.args[1]
+    assert "line-1" in sent_text
+    assert bot.WORKER_TERMINAL_SNAPSHOT_BUTTON_TEXT in sent_text
+
+
+def test_worker_terminal_snapshot_handles_tmux_failure(monkeypatch):
+    def fake_capture(_: int) -> str:
+        raise subprocess.CalledProcessError(returncode=1, cmd="tmux", output="err")
+
+    mock_reply = AsyncMock()
+
+    monkeypatch.setattr(bot, "_capture_tmux_recent_lines", fake_capture)
+    monkeypatch.setattr(bot, "_reply_to_chat", mock_reply)
+
+    message = _DummyMessage(bot.WORKER_TERMINAL_SNAPSHOT_BUTTON_TEXT)
+    asyncio.run(bot.on_tmux_snapshot_button(message))
+
+    assert mock_reply.await_count == 1
+    call = mock_reply.await_args
+    assert bot.TMUX_SESSION in call.args[1]
+
+
 def test_master_projects_button_accepts_legacy_text(monkeypatch):
     dummy_manager = _DummyManager()
 
@@ -257,9 +275,9 @@ def test_master_projects_button_uses_new_text_without_refresh(monkeypatch):
         (master.MASTER_MENU_BUTTON_TEXT, False),
         (f"{master.MASTER_MENU_BUTTON_TEXT} ", False),
         ("\u200b" + master.MASTER_MENU_BUTTON_TEXT + "\u200d", False),
-        ("📂Project list", True),
-        ("Project list", True),
-        (" Project list ", True),
+        ("📂项目列表", True),
+        ("项目列表", True),
+        (" 项目 列表 ", True),
         ("📂 Projects", True),
         ("projects", True),
         ("Project List", True),
@@ -333,17 +351,9 @@ def test_worker_broadcast_pushes_to_targets(tmp_path, monkeypatch):
 
     mock_bot = AsyncMock()
     asyncio.run(bot._broadcast_worker_keyboard(mock_bot))
-    assert mock_bot.send_message.await_count == 4
-    calls_by_chat: dict[int, list] = {}
-    for call in mock_bot.send_message.await_args_list:
-        chat_id = call.kwargs["chat_id"]
-        calls_by_chat.setdefault(chat_id, []).append(call.kwargs.get("reply_markup"))
-    assert set(calls_by_chat) == {333, 444}
-    for markups in calls_by_chat.values():
-        assert any(isinstance(markup, ReplyKeyboardMarkup) for markup in markups)
-        assert any(isinstance(markup, InlineKeyboardMarkup) for markup in markups)
-        reply_markup = next(markup for markup in markups if isinstance(markup, ReplyKeyboardMarkup))
-        assert reply_markup.keyboard[1][0].text == bot.WORKER_COMMAND_BUTTON_TEXT
+    assert mock_bot.send_message.await_count == 2
+    payload = {call.kwargs["chat_id"] for call in mock_bot.send_message.await_args_list}
+    assert payload == {333, 444}
 
     monkeypatch.delenv("STATE_FILE", raising=False)
     monkeypatch.delenv("MASTER_PROJECTS_PATH", raising=False)
