@@ -1,12 +1,15 @@
 """
-Test cases for testing master restart functionality
-Includes:
-1. Restart button should not refresh project list
-2. Restart requests should be handled correctly
-3. Other buttons should still refresh the item list
+测试 master 重启功能的测试用例
+包括：
+1. 重启按钮不应该刷新项目列表
+2. 重启请求应该被正确处理
+3. 其他按钮仍然应该刷新项目列表
 """
+from __future__ import annotations
+
 import asyncio
 import json
+from datetime import datetime
 from pathlib import Path
 from types import SimpleNamespace
 from unittest.mock import AsyncMock, patch
@@ -19,19 +22,19 @@ from project_repository import ProjectRepository
 
 @pytest.fixture(autouse=True)
 def reset_state():
-    """Reset global state"""
+    """重置全局状态"""
     master.PROJECT_WIZARD_SESSIONS.clear()
-    master.PROJECT_WIZARD_LOCK = asyncio.Lock()
+    master.reset_project_wizard_lock()
     yield
     master.PROJECT_WIZARD_SESSIONS.clear()
-    master.PROJECT_WIZARD_LOCK = asyncio.Lock()
+    master.reset_project_wizard_lock()
     master.PROJECT_REPOSITORY = None
     master.MANAGER = None
 
 
 @pytest.fixture
 def repo(tmp_path: Path, monkeypatch) -> ProjectRepository:
-    """Create a project repository for testing"""
+    """创建测试用的项目仓库"""
     config_dir = tmp_path / "config"
     config_dir.mkdir()
     json_path = config_dir / "projects.json"
@@ -54,7 +57,7 @@ def repo(tmp_path: Path, monkeypatch) -> ProjectRepository:
 
 
 def _build_manager(repo: ProjectRepository, tmp_path: Path) -> master.MasterManager:
-    """Build MasterManager instance"""
+    """构建 MasterManager 实例"""
     records = repo.list_projects()
     configs = [master.ProjectConfig.from_dict(record.to_dict()) for record in records]
     state_path = tmp_path / "state.json"
@@ -63,7 +66,7 @@ def _build_manager(repo: ProjectRepository, tmp_path: Path) -> master.MasterMana
 
 
 class DummyMessage:
-    """Simulate Telegram Message object"""
+    """模拟 Telegram Message 对象"""
     def __init__(self, chat_id: int = 1) -> None:
         self.text = ""
         self.chat = SimpleNamespace(id=chat_id)
@@ -84,7 +87,7 @@ class DummyMessage:
 
 
 class DummyCallback:
-    """Mock Telegram CallbackQuery object"""
+    """模拟 Telegram CallbackQuery 对象"""
     def __init__(self, data: str, chat_id: int = 1, message: DummyMessage | None = None) -> None:
         self.data = data
         self.from_user = SimpleNamespace(id=chat_id, username="tester")
@@ -97,46 +100,46 @@ class DummyCallback:
 
 def test_restart_master_does_not_refresh_project_list(repo: ProjectRepository, tmp_path: Path, monkeypatch):
     """
-    Test Case 1: Click"Restart Master"Item list should not be refreshed after pressing button
+    测试用例 1：点击"重启 Master"按钮后，不应该刷新项目列表
 
-    Verification point:
-    - Restart requests are handled correctly
-    - The message is not edited (the item list is not refreshed)
-    - Callback replies are sent correctly
+    验证点：
+    - 重启请求被正确处理
+    - 消息没有被编辑（不刷新项目列表）
+    - 回调答复正确发送
     """
     manager = _build_manager(repo, tmp_path)
     master.MANAGER = manager
 
-    # Create a startup script (to avoid reboot failures)
+    # 创建启动脚本（避免重启失败）
     start_script = tmp_path / "scripts" / "start.sh"
     start_script.parent.mkdir(parents=True, exist_ok=True)
     start_script.write_text("#!/bin/bash\necho 'mock start'", encoding="utf-8")
     start_script.chmod(0o755)
 
-    # Set ROOT_DIR to find the startup script
+    # 设置 ROOT_DIR 以便找到启动脚本
     monkeypatch.setattr(master, "ROOT_DIR", tmp_path)
 
-    # Analog restart signal writing
+    # 模拟重启信号写入
     signal_path = tmp_path / "state" / "restart_signal.json"
     signal_path.parent.mkdir(parents=True, exist_ok=True)
     monkeypatch.setattr(master, "RESTART_SIGNAL_PATH", signal_path)
 
-    # Create callback
+    # 创建回调
     callback_message = DummyMessage()
     callback = DummyCallback("project:restart_master:*", message=callback_message)
 
-    # Execute callback processing
+    # 执行回调处理
     async def _invoke():
-        # Mock _process_restart_request to avoid an actual reboot
+        # Mock _process_restart_request 以避免实际重启
         original_process = master._process_restart_request
 
         async def mock_restart(message, *, trigger_user=None, manager=None):
-            # Logging restart is called
+            # 记录重启被调用
             message._restart_called = True
-            await message.answer("The restart command has been received. The master will be temporarily offline during operation. After restarting, all workers need to be started manually later.")
+            await message.answer("已收到重启指令，运行期间 master 会短暂离线，重启后所有 worker 需稍后手动启动。")
 
         with patch.object(master, '_process_restart_request', new=mock_restart):
-            # Import FSMContext to call handler functions
+            # 导入 FSMContext 以便调用处理函数
             from aiogram.fsm.context import FSMContext
             from aiogram.fsm.storage.base import StorageKey
             from aiogram.fsm.storage.memory import MemoryStorage
@@ -149,30 +152,30 @@ def test_restart_master_does_not_refresh_project_list(repo: ProjectRepository, t
 
     asyncio.run(_invoke())
 
-    # Validation: callback should return"Restart command received"
-    assert callback._answers, "There should be a callback reply"
-    assert callback._answers[0][0] == "Restart command received", "The callback reply content should be correct"
+    # 验证：回调应该返回"已收到重启指令"
+    assert callback._answers, "应该有回调答复"
+    assert callback._answers[0][0] == "已收到重启指令", "回调答复内容应该正确"
 
-    # Validation: Message should not be edited (does not refresh item list)
-    assert len(callback_message._edits) == 0, "Messages should not be edited on restart (the project list is not refreshed)"
+    # 验证：消息不应该被编辑（不刷新项目列表）
+    assert len(callback_message._edits) == 0, "重启时不应该编辑消息（不刷新项目列表）"
 
-    # Verification: Restart request should be called
-    assert hasattr(callback_message, '_restart_called'), "The restart request should be called"
+    # 验证：重启请求应该被调用
+    assert hasattr(callback_message, '_restart_called'), "重启请求应该被调用"
 
 
 def test_other_actions_still_refresh_project_list(repo: ProjectRepository, tmp_path: Path, monkeypatch):
     """
-    Test Case 2: Other button actions (like stopping an item) should still refresh the item list
+    测试用例 2：其他按钮操作（如停止项目）仍然应该刷新项目列表
 
-    Verification point:
-    - Stop project requests are handled correctly
-    - Message is edited (refreshes item list)
+    验证点：
+    - 停止项目请求被正确处理
+    - 消息被编辑（刷新项目列表）
     """
     manager = _build_manager(repo, tmp_path)
     master.MANAGER = manager
     master.PROJECT_REPOSITORY = repo
 
-    # Set project status to running
+    # 设置项目状态为运行中
     manager.state_store.update("test", model="codex", status="running")
 
     # Mock stop_worker
@@ -181,7 +184,7 @@ def test_other_actions_still_refresh_project_list(repo: ProjectRepository, tmp_p
 
     monkeypatch.setattr(manager, "stop_worker", AsyncMock(side_effect=mock_stop_worker))
 
-    # Create callback
+    # 创建回调
     callback_message = DummyMessage()
     callback = DummyCallback("project:stop:test", message=callback_message)
 
@@ -198,26 +201,26 @@ def test_other_actions_still_refresh_project_list(repo: ProjectRepository, tmp_p
 
     asyncio.run(_invoke())
 
-    # Validate: the message should be edited (refresh the item list)
-    assert len(callback_message._edits) > 0, "The message should be edited after stopping the project (refresh the project list)"
+    # 验证：消息应该被编辑（刷新项目列表）
+    assert len(callback_message._edits) > 0, "停止项目后应该编辑消息（刷新项目列表）"
 
-    # Verification: The edited content should be an overview of the project
+    # 验证：编辑的内容应该是项目概览
     text, kwargs = callback_message._edits[0]
-    assert text == "Please select an action:", "Project overview should be refreshed"
+    assert text == "请选择操作：", "应该刷新项目概览"
 
 
 def test_restart_master_without_message_object(repo: ProjectRepository, tmp_path: Path):
     """
-    Test Case 3: Edge Scenario - Restart button callback missing message object
+    测试用例 3：边界场景 - 重启按钮回调缺少 message 对象
 
-    Verification point:
-    - Error logs should be logged
-    - should return immediately without performing a restart
+    验证点：
+    - 应该记录错误日志
+    - 应该立即返回，不执行重启
     """
     manager = _build_manager(repo, tmp_path)
     master.MANAGER = manager
 
-    # Create callback without message
+    # 创建没有 message 的回调
     callback = DummyCallback("project:restart_master:*")
     callback.message = None
 
@@ -232,28 +235,28 @@ def test_restart_master_without_message_object(repo: ProjectRepository, tmp_path
 
         await master.on_project_action(callback, fsm_state)
 
-    # Should not throw an exception
+    # 应该不抛出异常
     asyncio.run(_invoke())
 
-    # Verification: The callback should have a reply
-    assert callback._answers, "There should be a callback reply"
+    # 验证：回调应该有答复
+    assert callback._answers, "应该有回调答复"
 
 
 def test_restart_master_with_unauthorized_user(repo: ProjectRepository, tmp_path: Path, monkeypatch):
     """
-    Test Case 4: Abnormal Scenario - Unauthorized user attempts to restart
+    测试用例 4：异常场景 - 未授权用户尝试重启
 
-    Verification point:
-    - Restart requests from unauthorized users should be denied
-    - should be sent"Unauthorized"information
+    验证点：
+    - 应该拒绝未授权用户的重启请求
+    - 应该发送"未授权"消息
     """
     manager = _build_manager(repo, tmp_path)
     master.MANAGER = manager
 
-    # Set the authorized user to 999 and the callback user to 1
+    # 设置授权用户为 999，而回调用户为 1
     monkeypatch.setenv("MASTER_ADMIN_IDS", "999")
 
-    # Create startup script
+    # 创建启动脚本
     start_script = tmp_path / "scripts" / "start.sh"
     start_script.parent.mkdir(parents=True, exist_ok=True)
     start_script.write_text("#!/bin/bash\necho 'mock start'", encoding="utf-8")
@@ -261,7 +264,7 @@ def test_restart_master_with_unauthorized_user(repo: ProjectRepository, tmp_path
 
     monkeypatch.setattr(master, "ROOT_DIR", tmp_path)
 
-    # Create callback (user ID is 1)
+    # 创建回调（用户 ID 为 1）
     callback_message = DummyMessage(chat_id=1)
     callback = DummyCallback("project:restart_master:*", chat_id=1, message=callback_message)
 
@@ -278,17 +281,17 @@ def test_restart_master_with_unauthorized_user(repo: ProjectRepository, tmp_path
 
     asyncio.run(_invoke())
 
-    # Verification: There should be no restart called
-    # Due to Unauthorized, the callback handler should return early
+    # 验证：应该没有调用重启
+    # 由于未授权，回调处理应该在早期就返回
 
 
 def test_stop_all_refreshes_project_list(repo: ProjectRepository, tmp_path: Path, monkeypatch):
     """
-    Test Case 5: Verification"Stop all projects"button will refresh the project list
+    测试用例 5：验证"停止全部项目"按钮会刷新项目列表
 
-    Verification point:
-    - Stop all projects requests are processed correctly
-    - information is edited (refresh the project list)
+    验证点：
+    - 停止全部项目请求被正确处理
+    - 消息被编辑（刷新项目列表）
     """
     manager = _build_manager(repo, tmp_path)
     master.MANAGER = manager
@@ -301,7 +304,7 @@ def test_stop_all_refreshes_project_list(repo: ProjectRepository, tmp_path: Path
 
     monkeypatch.setattr(manager, "stop_all", AsyncMock(side_effect=mock_stop_all))
 
-    # Create callback
+    # 创建回调
     callback_message = DummyMessage()
     callback = DummyCallback("project:stop_all:*", message=callback_message)
 
@@ -318,5 +321,139 @@ def test_stop_all_refreshes_project_list(repo: ProjectRepository, tmp_path: Path
 
     asyncio.run(_invoke())
 
-    # Validate: the message should be edited (refresh the item list)
-    assert len(callback_message._edits) > 0, "Stop all projectsInformation should be edited later (refresh the project list)"
+    # 验证：消息应该被编辑（刷新项目列表）
+    assert len(callback_message._edits) > 0, "停止全部项目后应该编辑消息（刷新项目列表）"
+
+
+@pytest.mark.asyncio
+async def test_notify_restart_success_pushes_project_overview(repo: ProjectRepository, tmp_path: Path, monkeypatch):
+    """重启信号存在时，应该在上线通知后推送项目列表。"""
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+
+    restart_signal = tmp_path / "state" / "restart_signal.json"
+    restart_signal.parent.mkdir(parents=True, exist_ok=True)
+    payload = {
+        "chat_id": 321,
+        "timestamp": datetime.now(master.LOCAL_TZ).isoformat(),
+    }
+    restart_signal.write_text(json.dumps(payload), encoding="utf-8")
+
+    monkeypatch.setattr(master, "RESTART_SIGNAL_PATH", restart_signal)
+    monkeypatch.setattr(master, "LEGACY_RESTART_SIGNAL_PATHS", tuple())
+
+    overview_mock = AsyncMock()
+    monkeypatch.setattr(master, "_send_projects_overview_to_chat", overview_mock)
+    monkeypatch.setattr(master.asyncio, "sleep", AsyncMock())
+
+    bot = SimpleNamespace(send_message=AsyncMock())
+
+    await master._notify_restart_success(bot)
+
+    overview_mock.assert_awaited_once()
+    called_bot, called_chat, _manager = overview_mock.await_args_list[0].args[:3]
+    assert called_bot is bot
+    assert called_chat == payload["chat_id"]
+    assert _manager is manager
+
+
+@pytest.mark.asyncio
+async def test_notify_restart_success_missing_signal_triggers_admin_overview(repo: ProjectRepository, tmp_path: Path, monkeypatch):
+    """缺少重启信号但预期重启时，应向管理员推送项目列表。"""
+    manager = _build_manager(repo, tmp_path)
+    manager.admin_ids = [111, 222]
+    master.MANAGER = manager
+
+    monkeypatch.setenv("MASTER_RESTART_EXPECTED", "1")
+    monkeypatch.setattr(master, "RESTART_SIGNAL_PATH", tmp_path / "state" / "restart_signal.json")
+    monkeypatch.setattr(master, "LEGACY_RESTART_SIGNAL_PATHS", tuple())
+
+    overview_mock = AsyncMock()
+    monkeypatch.setattr(master, "_send_projects_overview_to_chat", overview_mock)
+    monkeypatch.setattr(master.asyncio, "sleep", AsyncMock())
+
+    bot = SimpleNamespace(send_message=AsyncMock())
+
+    await master._notify_restart_success(bot)
+
+    assert overview_mock.await_count == len(manager.admin_ids)
+    called_ids = sorted(call.args[1] for call in overview_mock.await_args_list)
+    assert called_ids == sorted(manager.admin_ids)
+
+
+@pytest.mark.asyncio
+async def test_notify_restart_success_invalid_chat_id_fallback(repo: ProjectRepository, tmp_path: Path, monkeypatch):
+    """重启信号 chat_id 异常时，应退回管理员推送。"""
+    manager = _build_manager(repo, tmp_path)
+    manager.admin_ids = [333]
+    master.MANAGER = manager
+
+    restart_signal = tmp_path / "state" / "restart_signal.json"
+    restart_signal.parent.mkdir(parents=True, exist_ok=True)
+    payload = {
+        "chat_id": "invalid",
+        "timestamp": datetime.now(master.LOCAL_TZ).isoformat(),
+    }
+    restart_signal.write_text(json.dumps(payload), encoding="utf-8")
+    monkeypatch.setattr(master, "RESTART_SIGNAL_PATH", restart_signal)
+    monkeypatch.setattr(master, "LEGACY_RESTART_SIGNAL_PATHS", tuple())
+
+    overview_mock = AsyncMock()
+    monkeypatch.setattr(master, "_send_projects_overview_to_chat", overview_mock)
+    monkeypatch.setattr(master.asyncio, "sleep", AsyncMock())
+
+    bot = SimpleNamespace(send_message=AsyncMock())
+
+    await master._notify_restart_success(bot)
+
+    overview_mock.assert_awaited_once()
+    assert overview_mock.await_args_list[0].args[1] == manager.admin_ids[0]
+
+
+@pytest.mark.asyncio
+async def test_notify_restart_success_send_failure_triggers_admin_overview(repo: ProjectRepository, tmp_path: Path, monkeypatch):
+    """上线通知发送失败时，应改为向管理员广播项目列表。"""
+    manager = _build_manager(repo, tmp_path)
+    manager.admin_ids = [444, 555]
+    master.MANAGER = manager
+
+    restart_signal = tmp_path / "state" / "restart_signal.json"
+    restart_signal.parent.mkdir(parents=True, exist_ok=True)
+    payload = {
+        "chat_id": 999,
+        "timestamp": datetime.now(master.LOCAL_TZ).isoformat(),
+    }
+    restart_signal.write_text(json.dumps(payload), encoding="utf-8")
+    monkeypatch.setattr(master, "RESTART_SIGNAL_PATH", restart_signal)
+    monkeypatch.setattr(master, "LEGACY_RESTART_SIGNAL_PATHS", tuple())
+
+    overview_mock = AsyncMock()
+    monkeypatch.setattr(master, "_send_projects_overview_to_chat", overview_mock)
+    monkeypatch.setattr(master.asyncio, "sleep", AsyncMock())
+
+    bot = SimpleNamespace(send_message=AsyncMock(side_effect=RuntimeError("send failed")))
+
+    await master._notify_restart_success(bot)
+
+    assert overview_mock.await_count == len(manager.admin_ids)
+    called_ids = sorted(call.args[1] for call in overview_mock.await_args_list)
+    assert called_ids == sorted(manager.admin_ids)
+
+
+@pytest.mark.asyncio
+async def test_send_restart_project_overview_deduplicates_chats(repo: ProjectRepository, tmp_path: Path, monkeypatch):
+    """项目列表推送应去重，防止触发人重复收到。"""
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+
+    overview_mock = AsyncMock()
+    monkeypatch.setattr(master, "_send_projects_overview_to_chat", overview_mock)
+    monkeypatch.setattr(master.asyncio, "sleep", AsyncMock())
+
+    bot = SimpleNamespace()
+
+    await master._send_restart_project_overview(bot, [1, 1, 2])
+
+    assert overview_mock.await_count == 2
+    called_ids = sorted(call.args[1] for call in overview_mock.await_args_list)
+    assert called_ids == [1, 2]
